@@ -21,9 +21,8 @@ extern "C" char ** environ;
 // test key is located at src/plugins/crypto/test_key.asc
 #define GPG_TEST_KEY_ID "DDEBEF9EE2DC931701338212DAF635B17F230E8D"
 
-enum PluginVariant
-{
-	NO_CRYPTO = 0,
+enum PluginVariant {
+	NO_CRYPTO = 0, ///< use no crypto variant
 	CRYPTO_OPENSSL = 1,
 	CRYPTO_GCRYPT = 2,
 	CRYPTO_BOTAN = 3,
