@@ -13,7 +13,6 @@
 #include "gpg.h"
 #include "helper.h"
 
-#include <base64_functions.h>
 #include <errno.h>
 #include <gcrypt.h>
 #include <kdbassert.h>
@@ -51,7 +50,12 @@ static int getKeyIvForEncryption (KeySet * config, Key * errorKey, Key * masterK
 
 	// generate the salt
 	gcry_create_nonce (salt, sizeof (salt));
-	saltHexString = ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME_C, base64Encode) (salt, sizeof (salt));
+	const int encodingResult = CRYPTO_PLUGIN_FUNCTION (base64Encode) (errorKey, salt, sizeof (salt), &saltHexString);
+	if (encodingResult < 0)
+	{
+		// error in libinvoke - errorKey has been set by base64Encode
+		return -1;
+	}
 	if (!saltHexString)
 	{
 		ELEKTRA_SET_ERROR (87, errorKey, "Memory allocation failed");
@@ -434,9 +438,13 @@ int elektraCryptoGcryDecrypt (elektraCryptoHandle * handle, Key * k, Key * error
  */
 char * elektraCryptoGcryCreateRandomString (Key * errorKey, const kdb_unsigned_short_t length)
 {
+	char * encoded = NULL;
 	kdb_octet_t buffer[length];
 	gcry_create_nonce (buffer, length);
-	char * encoded = ELEKTRA_PLUGIN_FUNCTION (ELEKTRA_PLUGIN_NAME_C, base64Encode) (buffer, length);
+	if (CRYPTO_PLUGIN_FUNCTION (base64Encode) (errorKey, buffer, length, &encoded) < 0)
+	{
+		return NULL;
+	}
 	if (!encoded)
 	{
 		ELEKTRA_SET_ERROR (87, errorKey, "Memory allocation failed");
