@@ -3,13 +3,13 @@
  *
  * @brief
  *
- * @copyright BSD License (see doc/LICENSE.md or http://www.libelektra.org)
+ * @copyright BSD License (see LICENSE.md or https://www.libelektra.org)
  */
 
 #include <mntent.h>
 #include <stdio.h>
 
-int main ()
+int main (void)
 {
 	struct mntent * m;
 	FILE * f;
