@@ -19,16 +19,31 @@
 
 int elektraJournaldGet (Plugin * handle ELEKTRA_UNUSED, KeySet * returned, Key * parentKey ELEKTRA_UNUSED)
 {
-	KeySet * n;
-	ksAppend (returned,
-		  n = ksNew (30, keyNew ("system/elektra/modules/journald", KEY_VALUE, "journald plugin waits for your orders", KEY_END),
-			     keyNew ("system/elektra/modules/journald/exports", KEY_END),
-			     keyNew ("system/elektra/modules/journald/exports/get", KEY_FUNC, elektraJournaldGet, KEY_END),
-			     keyNew ("system/elektra/modules/journald/exports/set", KEY_FUNC, elektraJournaldSet, KEY_END),
-			     keyNew ("system/elektra/modules/journald/exports/error", KEY_FUNC, elektraJournaldError, KEY_END),
+	if (!strcmp (keyName (parentKey), "system/elektra/modules/journald"))
+	{
+		KeySet * n;
+		ksAppend (
+			returned,
+			n = ksNew (30,
+				   keyNew ("system/elektra/modules/journald", KEY_VALUE, "journald plugin waits for your orders", KEY_END),
+				   keyNew ("system/elektra/modules/journald/exports", KEY_END),
+				   keyNew ("system/elektra/modules/journald/exports/get", KEY_FUNC, elektraJournaldGet, KEY_END),
+				   keyNew ("system/elektra/modules/journald/exports/set", KEY_FUNC, elektraJournaldSet, KEY_END),
+				   keyNew ("system/elektra/modules/journald/exports/error", KEY_FUNC, elektraJournaldError, KEY_END),
 #include "readme_journald.c"
-			     keyNew ("system/elektra/modules/journald/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END));
-	ksDel (n);
+				   keyNew ("system/elektra/modules/journald/infos/version", KEY_VALUE, PLUGINVERSION, KEY_END), KS_END));
+		ksDel (n);
+		return 1;
+	}
+
+	if (strncmp (keyString (ksLookupByName (elektraPluginGetConfig (handle), "/log/get", 0)), "1", 1) == 0)
+	{
+		sd_journal_send ("MESSAGE=loading configuration %s", keyName (parentKey), "MESSAGE_ID=fc65eab25c18463f97e4f9b61ea31eae",
+				 "PRIORITY=5", /* notice priority */
+				 "HOME=%s", getenv ("HOME"), "USER=%s", getenv ("USER"), "PAGE_SIZE=%li", sysconf (_SC_PAGESIZE),
+				 "N_CPUS=%li", sysconf (_SC_NPROCESSORS_ONLN), NULL);
+	}
+
 	return 1;
 }
 
@@ -60,4 +75,3 @@ Plugin * ELEKTRA_PLUGIN_EXPORT (journald)
 		ELEKTRA_PLUGIN_ERROR,	&elektraJournaldError,
 		ELEKTRA_PLUGIN_END);
 }
-
