@@ -37,7 +37,7 @@ int elektraNetworkAddrInfo (Key * toCheck)
 	hints.ai_flags = AI_NUMERICHOST; /* Only accept numeric hosts */
 	hints.ai_protocol = 0;		 /* Any protocol */
 
-	s = getaddrinfo (keyString (toCheck), "", &hints, &result);
+	s = getaddrinfo (keyString (toCheck), NULL, &hints, &result);
 
 	if (s != 0)
 	{
