@@ -153,8 +153,10 @@ void MountBaseCommand::doIt ()
 		throw KDBMountException (std::string (e.what ()) +
 					 "\n\n"
 					 "IMPORTANT: Sorry, I am unable to write your requested mountpoint to system/elektra/mountpoints.\n"
-					 "           Please make sure that you can write to `Configfile:` as mentioned above.\n"
-					 "           Usually you need to be root for that (use `sudo !!`).");
+					 "           Please make sure that you can write to `Configfile:` as mentioned above.\n" +
+					 getErrorColor (ANSI_COLOR::BOLD) + getErrorColor (ANSI_COLOR::YELLOW) +
+					 "           Usually you need to be root for this operation (try `sudo !!`)." +
+					 getErrorColor (ANSI_COLOR::RESET));
 	}
 
 	printWarnings (cerr, parentKey);
