@@ -32,17 +32,15 @@ public:
 	/**
 	 * @brief GUIBackend The mandatory copy constructor.
 	 */
-	GUIBackend (const GUIBackend & other) : QObject ()
-	{
-		Q_UNUSED (other)
-	}
+	GUIBackend (const GUIBackend & other)
+	: QObject (){ Q_UNUSED (other) }
 
-	/**
-	 * @brief Creates a new backend on a mountpoint.
-	 *
-	 * @param mountpoint The mountpoint of the new backend.
-	 */
-	Q_INVOKABLE void createBackend (const QString & mountpoint);
+	  /**
+	   * @brief Creates a new backend on a mountpoint.
+	   *
+	   * @param mountpoint The mountpoint of the new backend.
+	   */
+	  Q_INVOKABLE void createBackend (const QString & mountpoint);
 
 	/**
 	 * @brief Add path to a backend fallback file.
@@ -156,7 +154,8 @@ signals:
 	 * @brief Triggers a messagedialog in the GUI.
 	 * @param title The title of the messagedialog in the GUI.
 	 * @param text The text of the messagedialog in the GUI.This is the text that will be initially shown to the user.
-	 * @param detailedText The detailed text of the messagedialog in the GUI.The user will have to click on a button to access this text.
+	 * @param detailedText The detailed text of the messagedialog in the GUI.The user will have to click on a button to access this
+	 * text.
 	 */
 	void showMessage (QString title, QString text, QString detailedText) const;
 };
