@@ -17,6 +17,8 @@ import keyReducer from './kdb'
 import pathReducer from './ls'
 import errorReducer from './error'
 import notificationReducer from './notification'
+import batchUndoReducer from './batchUndo'
+import kdbFindReducer from './kdbFind'
 
 export default combineReducers({
   idle: idleReducer,
@@ -27,4 +29,6 @@ export default combineReducers({
   error: errorReducer,
   notification: notificationReducer,
   undoHistory: undoHistoryReducer,
+  batchUndo: batchUndoReducer,
+  kdbFind: kdbFindReducer,
 })
