@@ -10,7 +10,9 @@ export const prettyprint = (obj) =>
   JSON.stringify(obj, null, 2)
 
 export const successResponse = (res, output) =>
-  output ? res.send(prettyprint(output)) : res.status(404).send()
+  output
+    ? res.json(output)
+    : res.send()
 
 export const errorResponse = (res, err) =>
-  res.status(400).send(prettyprint({ error: err }))
+  res.status(400).json({ error: err })
