@@ -18,7 +18,7 @@ fi
 
 check_version
 
-EXTERNAL_FOLDER=@CMAKE_SOURCE_DIR@/examples/external
+EXTERNAL_FOLDER="@CMAKE_SOURCE_DIR@/examples/external"
 
 set -x
 
@@ -27,11 +27,11 @@ do_tests()
 	SKEY=system/test/myapp/key
 	UKEY=user/test/myapp/key
 
-	$KDB rm "$SKEY"
-	$KDB rm "$UKEY"
+	"$KDB" rm "$SKEY"
+	"$KDB" rm "$UKEY"
 
 	VALUE="Hello World"
-	$KDB set "$SKEY"  "$VALUE"
+	"$KDB" set "$SKEY"  "$VALUE"
 	succeed_if "could not set key $SKEY"
 
 	./application
@@ -39,22 +39,22 @@ do_tests()
 	succeed_if "application did not output $VALUE"
 
 	VALUE="More world"
-	$KDB set "$UKEY"  "$VALUE"
+	"$KDB" set "$UKEY"  "$VALUE"
 	succeed_if "could not set key $SKEY"
 
 	./application
 	./application | grep "$VALUE"
 	succeed_if "application did not prefer $UKEY with $VALUE"
 
-	$KDB rm "$SKEY"
-	$KDB rm "$UKEY"
+	"$KDB" rm "$SKEY"
+	"$KDB" rm "$UKEY"
 }
 
 
 
 echo "Testing build with cmake"
 
-cd $EXTERNAL_FOLDER
+cd "$EXTERNAL_FOLDER"
 mkdir build
 cd build
 
@@ -74,7 +74,7 @@ rm -r build
 
 echo "Testing build with pkgconfig"
 
-cd $EXTERNAL_FOLDER/pkgconfig
+cd "$EXTERNAL_FOLDER/pkgconfig"
 make
 succeed_if "could not build pkgconfig project"
 
