@@ -22,7 +22,7 @@ else
 	exit
 fi
 
-if test -x /usr/bin/python
+if /usr/bin/env python2 -V &> /dev/null
 then
 	echo "python available"
 else
@@ -30,13 +30,31 @@ else
 	exit
 fi
 
+if /usr/bin/env python2 -c 'from Cheetah.Template import Template' 2> /dev/null
+then
+	echo "Cheetah available"
+else
+	echo "Cheetah not available"
+	exit
+fi
+
+[ -z "${CC}" ] && CC=gcc
+[ -z "${CXX}" ] && CXX=g++
+if "${CC}" --version 2> /dev/null | grep -Eq '^gcc'
+then
+	echo "GCC available"
+else
+	echo "GCC not available"
+	exit
+fi
+
 GEN_FOLDER="@CMAKE_SOURCE_DIR@/src/tools/gen"
 GEN="$GEN_FOLDER/gen"
 
 TESTPROGS="./lift ./cpplift ./nestedlift ./dynamiccontextlift"
 # ./staticcontextlift commented out
 
-if $GEN -h | grep "^usage:"
+if "$GEN" -h | grep "^usage:"
 then
 	echo "$GEN available"
 else
@@ -68,10 +86,10 @@ succeed_if "could not mount: $HEAVY_MATERIAL_LIFT_FILE at $HEAVY_MATERIAL_LIFT_M
 
 
 
-cd $GEN_FOLDER
+cd "$GEN_FOLDER"
 
 
-BUILD_DIR="@CMAKE_BINARY_DIR@" make
+BUILD_DIR="@CMAKE_BINARY_DIR@" make CC="${CC}" CXX="${CXX}"
 
 
 
@@ -138,8 +156,8 @@ echo "Test wrong commandline arguments"
 ./lift -d -2 | grep "Error in parsing options 16"
 succeed_if "negative number accepted"
 
-./lift -d no | grep "Error in parsing options 8"
-succeed_if "string as int accepted"
+# ./lift -d no | grep "Error in parsing options 8"
+# succeed_if "string as int accepted"
 
 ./lift -a ksks | grep "Error in parsing options 64"
 succeed_if "wrong string as enum accepted"
